@@ -1,27 +1,35 @@
-import pandas as pd
-from AuDoLab.subclasses import abstractscraper
-from AuDoLab.subclasses import lda
-from AuDoLab.subclasses import one_class_svm
-from AuDoLab.subclasses import preprocessing
-from AuDoLab.subclasses import tf_idf
-from AuDoLab.subclasses import abstractscraper_arxiv
-from AuDoLab.subclasses import abstractscraper_pubmed
+import warnings
+import asyncio
 import sys
+from AuDoLab.subclasses import abstractscraper_pubmed
+from AuDoLab.subclasses import abstractscraper_arxiv
+from AuDoLab.subclasses import tf_idf
+from AuDoLab.subclasses import preprocessing
+from AuDoLab.subclasses import one_class_svm
+from AuDoLab.subclasses import lda
+from AuDoLab.subclasses import abstractscraper
+import pandas as pd
+
+
+def warn(*args, **kwargs):
+    pass
+
+
+warnings.warn = warn
 
 
 class AuDoLab:
-    """TODO
-        1) call asyncio func directly in class such that the user does not need to call advanced loop
-        2) Remove depreciationwarnings (scipy.sparse and imp)
-        3) include pyldavis function (or remove completely depending on utility for users)
-        4) adapt documentation that it is consistent within itself (documentation = summarys and datatypes)
-        5) check if further functions needed -> second loop of iteration in decision rule from (https://www.researchgate.net/profile/Astrid-Krenz/publication/344432349_Unsupervised_Document_Classification_integrating_Web_Scraping_One-Class_SVM_and_LDA_Topic_Modelling/links/5f749c97458515b7cf596d36/Unsupervised-Document-Classification-integrating-Web-Scraping-One-Class-SVM-and-LDA-Topic-Modelling.pdf)
 
-    """
     def __init__(self):
-        4 + 4
+        self.loop = asyncio.get_event_loop()
+        if self._is_notebook():
+            # prevent runtime error with asyncio in ipynb:
+            # https://medium.com/@vyshali.enukonda/how-to-get-around-runtimeerro
+            # r-this-event-loop-is-already-running-3f26f67e762e
+            import nest_asyncio
+            nest_asyncio.apply()
 
-    async def ieee_scraper(
+    def get_ieee(
         self,
         url=None,
         keywords=None,
@@ -32,6 +40,7 @@ class AuDoLab:
         ngram_type=2,
     ):
         """Function to scrape abstracts of scientific papers from the givin url.
+
         We used https://ieeexplore.ieee.org/search/advanced to generate a
         list like https://ieeexplore.ieee.org/search/searchresult.jsp?action=se
         arch&newsearch=true&matchBoolean=true&queryText=(%22Author%20Keywords%22
@@ -42,32 +51,70 @@ class AuDoLab:
         be stored in a .txt file with the givin file name.
 
         Args:
-            url (str, optional): [description]. Defaults to None.
-            keywords (list, optional): List of keywords that are searched for. Defaults to None.
-            operator (str, optional): Operator between the keywords. "AND" or "OR". If "AND" the search results must include all keywords. Defaults to "OR".
-            pages (int, optional): Number of pages that are iterated over. Translates directly to number of abstracts that are scraped. Roughly there are 100 abstracts scraped per page. Defaults to 2.
-            in_data (str, optional): If the keywords are searched for in the author keywords or in all metadata. Defaults to "author".
-            prepro (bool, optional): if True, the scraped data will directly be preprocessed for later use. Defaults to False.
-            ngram_type (int, optional): number of ngrams in preprocessing. Defaults to 2.
+            url (str, optional): The url of the website, whos presented paper
+                abstracs will be scraped. Defaults to None.
+
+            keywords (list, optional): List of keywords that are searched
+                for. Defaults to None.
+
+            keywords (iist, optional): keywords that are searched for.
+                Defaults to None.
+
+            operator (str, optional): Operator between the keywords.
+                "AND" or "OR". If "AND" the search results must include all
+                keywords. Defaults to "OR".
+
+            pages (int, optional): Number of pages that are iterated over.
+                Translates directly to number of abstracts that are scraped.
+                Roughly there are 100 abstracts scraped per page. Defaults to 2.
+
+            in_data (str, optional): If the keywords are searched for in the
+                author keywords or in all metadata. Defaults to "author".
+
+            prepro (bool, optional): if True, the scraped data will directly be
+                preprocessed for later use. Defaults to False.
+
+            ngram_type (int, optional): number of ngrams in preprocessing.
+                Defaults to 2.
 
         Returns:
             pd.DataFrame: DataFrame with the stored abstracts and metadata
         """
+        return self.loop.run_until_complete(self.__async__get_ieee(
+            "https://ieeexplore.ieee.org/search/searchresult.jsp?newsearch=true&queryText=cotton&highlight=true&returnFacets=ALL&returnType=SEARCH&matchPubs=true&rowsPerPage=100&pageNumber=1",
+            prepro=True,
+            pages=pages,
+        ))
+
+    async def __async__get_ieee(
+        self,
+        url=None,
+        keywords=None,
+        operator="OR",
+        pages=2,
+        in_data="author",
+        prepro=False,
+        ngram_type=2,
+    ):
 
         number = pages
 
         ks = abstractscraper.AbstractScraper()
         self.abstracts = await ks.get_abstracts(
-            url=url, keywords=keywords, operator=operator, pages=number, in_data=in_data
+            url=url,
+            keywords=keywords,
+            operator=operator,
+            pages=number,
+            in_data=in_data
         )
 
-        if prepro == True:
+        if prepro is True:
             self.abstracts = self.abstracts.reset_index(drop=True)
             self.abstracts = self.text_cleaning(
                 self.abstracts, "abstract", ngram_type=ngram_type
             )
 
-        if type(self.abstracts) != pd.DataFrame:
+        if not isinstance(self.abstracts, pd.DataFrame):
             print(
                 "if using the ieee abstractscraper, please use the following code: \n \n"
                 + "async def scrape():"
@@ -84,14 +131,24 @@ class AuDoLab:
     def abstract_scraper(
         self, type="arxiv", url=None, pages=2, prepro=False, ngram_type=2
     ):
-        """Scapes the pages arxiv.org and pubmed.gov for paper abstracts
+        """Scrapes the pages arxiv.org, pubmed.gov for paper abstracts
 
         Args:
-            type (str, optional): "arxiv" or "pubmed". Defines for which page the scraping is done. Defaults to "arxiv".
-            url (str, optional): The given url after which the papers are scraped. Must be in line with type. Defaults to None.
-            pages (int, optional): Number of pages that are iterated over. Defaults to 2.
-            prepro (bool, optional): If True, the scraped documents are preprocessed directly. Defaults to False.
-            ngram_type (int, optional): Number of ngrams in preprocessing. Defaults to 2.
+            type (str, optional): "arxiv" or "pubmed". Defines for which page
+                the scraping is done. Defaults to "arxiv".
+
+            url (str, optional): The given url after which the papers are
+                scraped. Must be in line with type. Defaults to None.
+
+            pages (int, optional): Number of pages that are iterated over.
+                Defaults to 2.
+
+            prepro (bool, optional): If True, the scraped documents are
+
+            preprocessed directly. Defaults to False.
+
+            ngram_type (int, optional): Number of ngrams in preprocessing.
+                Defaults to 2.
 
         Returns:
             pd.DataFrame: DataFrame with the stored abstracts
@@ -107,7 +164,7 @@ class AuDoLab:
 
         self.abstracts = self.abstracts.reset_index(drop=True)
 
-        if prepro == True:
+        if prepro is True:
             self.abstracts = self.text_cleaning(
                 self.abstracts, "abstract", ngram_type=ngram_type
             )
@@ -119,12 +176,16 @@ class AuDoLab:
         deleted.
 
         Args:
-            data (pd.DataFrame): Dataframe where the documents to be preprocessed are stored
+            data (pd.DataFrame): Dataframe where the documents to be
+                preprocessed are stored
+
             column (str): Column name of the column where docs are stored
+
             ngram_type (int, optional): Number of ngrams used. Defaults to 2.
 
         Returns:
-            pd.DataFrame: DataFrame where the original docus and the preprocessed documents are stored
+            pd.DataFrame: DataFrame where the original docus and the
+                preprocessed documents are stored
         """
 
         prepro = preprocessing.Preprocessor()
@@ -133,28 +194,43 @@ class AuDoLab:
         )
         return self.data_processed
 
-    def tf_idf(self, data, papers, data_column, papers_column, features=None, ngrams=2):
-        """[creates tf-idf objects for one-class SVM classification. The tf-idf
-        scores are calculated over a joint corpus,
-        however, the target data and the out-of-domain training data are stored
-        in seperate, as the one-class SVM is only trained on
-        the tf-idf scores of the out-of-domain training data]
+    def tf_idf(
+        self,
+        data,
+        papers,
+        data_column,
+        papers_column,
+        features=None,
+        ngrams=2
+    ):
+        """Creates tf-idf objects for one-class SVM classification.
+
+        The tf-idf scores are calculated over a joint corpus, however the target
+        data and the out-of-domain training data are stored in seperate, as the
+        one-class SVM is only trained on the tf-idf scores of the out-of-domain
+        training data.
 
         Args:
-            data (DataFrame): [preprocessed target documents]
-            papers (DataFrame): [preprocessed out-of-domain training data]
-            data_colum (String): [name of columnin target dataframe where
-            lemmatized documents are stored]. Defaults to 'lemma'
-            papers_colum (String): [name of column in out-of-domain training
-            dataframe where lemmatized documents are stored]. Defaults to
-            'lemma' ngrams (int, optional): [whether ngram are formed].
-            Defaults to 2.
-            features (int, optional): [number of max features].
-            Defaults to 8000.
+            data (DataFrame): preprocessed target documents
+
+            papers (DataFrame): preprocessed out-of-domain training data
+
+            data_colum (String): name of columnin target dataframe where
+                lemmatized documents are stored. Defaults to 'lemma'
+
+            papers_colum (String): name of column in out-of-domain training
+                dataframe where lemmatized documents are stored. Defaults to
+                'lemma'
+
+            ngrams (int, optional): whether ngram are formed.
+                Defaults to 2.
+
+            features (int, optional): number of max features.
+                Defaults to 8000.
 
         Returns:
-            [data and papers]: [tfidf object data for target data and
-             ou-of-domain training data]
+            data and papers: tfidf object data for target data and
+                out-of-domain training data
         """
 
         tfidf = tf_idf.Tf_idf()
@@ -174,25 +250,37 @@ class AuDoLab:
         gamma="auto",
         kernel="rbf",
     ):
-        """[summary]
+        """Returns the classifiers that fullfill the required conditions.
 
         Args:
             training (DataFrame): training dataset of preprocessed documents
+
             predicting (DataFrame): target dataset of preprccessed documents
-            nus (list of floats): hyperparameters over which are looped. For each nu the classifier is trained
-            quality_train (float, optional): percentage of training data that seems to
-                                    belong to target class. Default: 0.85. Defaults to 0.85.
-            min_pred (float, optional): percentage of target data that has to be at
-                               least classified as belonging to target class
-            for classifier to be considered. Default: 0.0. Defaults to 0.05.
-            max_pred (float, optional): percentage of target class that is maximally
-                               allowed to be classified as belonging to
+
+            nus (list of floats): hyperparameters over which are looped. For
+                each nu the classifier is trained
+
+            quality_train (float, optional): percentage of training data that
+                seems to belong to target class. Default: 0.85. Defaults to
+                0.85.
+
+            min_pred (float, optional): percentage of target data that has to be
+                at least classified as belonging to target class for classifier
+                to be considered. Default: 0.0. Defaults to 0.05.
+
+            max_pred (float, optional): percentage of target class that is
+                maximally allowed to be classified as belonging to
+
             target class for classifier to be considered.. Defaults to 0.2.
+
             gamma (str, optional): Hyperparamter of O-SVM. Defaults to "auto".
-            kernel (str, optional): Kernel function used in O_SVM. Defaults to "rbf".
+
+            kernel (str, optional): Kernel function used in O_SVM. Defaults to
+                "rbf".
 
         Returns:
-            pd.DataFrame: DataFrame with stored classifiers that fulfill conditions
+            pd.DataFrame: DataFrame with stored classifiers that fulfill
+                conditions
         """
 
         one_Class_SVM = one_class_svm.One_Class_SVM()
@@ -210,20 +298,18 @@ class AuDoLab:
         return self.df
 
     def choose_classifier(self, df, classifier, i):
-        """
-        returns dataframe where documents that are classified to target class
+        """Returns dataframe where documents that are classified to target class
         have 1, otherwise, 0
 
-        :param df: dataframe of target documents
-        :type df: pd.Dataframe
-        :param classifier: list of all possible o-svm classifiers
-        :type classifier: list
-        :param i: index of which classifier is chosen/preferred
-        :type i: int
+        Args:
+            df (pd.Dataframe): dataframe of target documents
 
-        :return: documents that are classified as belonging to target
-        :rtype: pd.dataframe
-            class by o-svm
+            classifier (list): list of all possible o-svm classifiers
+
+            i (int): index of which classifier is chosen/preferred
+
+        Returns:
+            pd.dataframe: documents that are classified as belonging to target
         """
         return one_class_svm.One_Class_SVM.choose_classifier(df, classifier, i)
 
@@ -248,22 +334,39 @@ class AuDoLab:
         https://www.jmlr.org/papers/volume3/blei03a/blei03a.pdf paper.
 
         Args:
-            corpus (iterable of list of (int, float), optional): Stream of document vectors or sparse matrix of shape
-            num_topics (int): pre-defined number of topics]
-            id2word ({dict of (int, str): gensim.corpora.dictionary.Dictionary}) –Mapping from word IDs to words. It is used to determine the vocabulary size, as well as for debugging and topic printing.
-            random_state (int): for recreating exact identical output. Defaults to 101.
-            passes (int): Number of passes through the corpus during training.Defaults to 20.
+            corpus (iterable of list of (int, float), optional): Stream of
+                document vectors or sparse matrix of shape
+
+            num_topics (int): pre-defined number of topics
+
+            id2word ({dict of (int, str): gensim.corpora.dictionary.Dictionary})
+                –Mapping from word IDs to words. It is used to determine the
+                vocabulary size, as well as for debugging and topic printing.
+
+            random_state (int): for recreating exact identical output. Defaults
+                to 101.
+
+            passes (int): Number of passes through the corpus during training.
+                Defaults to 20.
+
             chunksize (int, optional): chunksize in lda passes. Defaults to 500.
+
             eta (str, optional): [description]. Defaults to "auto".
-            eval_every ([type], optional): Hyperparameter in LDA used to initiliaze the Dirichlet distribution. Defaults to None.
-            multi (bool, optional): If true, the in gensim incorporated multicore variant is used. Defaults to True.
-            alpha (str, optional): OTher Dirichlet Prior. Defaults to "asymmetric".
+
+            eval_every ([type], optional): Hyperparameter in LDA used to
+                initiliaze the Dirichlet distribution. Defaults to None.
+
+            multi (bool, optional): If true, the in gensim incorporated
+                multicore variant is used. Defaults to True.
+
+            alpha (str, optional): OTher Dirichlet Prior. Defaults to
+                "asymmetric".
 
         Returns:
-            [lda_model]: [returns lda_model output]
+            lda_model: returns lda_model output
         """
 
-        if corpus == None:
+        if corpus is None:
             self.dictionary, self.bow_corpus = lda.LDA.preperation(
                 data, no_below, no_above, column=column
             )
@@ -287,6 +390,18 @@ class AuDoLab:
         )
         return self.lda_model
 
+    def _is_notebook(self):
+        try:
+            shell = get_ipython().__class__.__name__
+            if shell == 'ZMQInteractiveShell':
+                return True   # Jupyter notebook or qtconsole
+            elif shell == 'TerminalInteractiveShell':
+                return False  # Terminal running IPython
+            else:
+                return False  # Other type (?)
+        except NameError:
+            return False      # Probably standard Python interpreter
+
     def lda_visualize_topics(
         self,
         save_name="audolab_model.png",
@@ -306,38 +421,46 @@ class AuDoLab:
     ):
         """Visualizes the topic models output in wordclouds or pyldavis
 
-        TODO: pyldavis not yet working, especially not in jupyter notebooks. MAybe take out all together
-
         Args:
             lda_model (gensim.models.ldamodel.LdaModel): the created LDA model
+
             bow_corpus (gensim.corpora.dictionary.Dictionary): Bag of words corpus of used documents
+
             dictionary (gensim.corpora.dictionary.Dictionary): Dictionary of all words
+
             save_name (str, optional): name under which the plots should be save. Defaults to "audolab_model.png".
+
             type (str, optional): type of visualisation- either "clouds" or "pyldavis". Defaults to "clouds".
+
             figsize (tuple, optional): Size of wordclouds. Defaults to (50, 30).
+
             facecolor (str, optional): Colour of wordcloud Defaults to "k".
+
             width (int, optional): width of plots. Defaults to 2000.
+
             height (int, optional): height of plots. Defaults to 1000.
+
             background_color (str, optional): Background colour of wordcloud. Defaults to "white".
+
             topic (int, optional): IF only one wordcloud is plotted, index of topic that is plotted. Defaults to 0.
+
             words (int, optional): Number of words per cloud. Defaults to 100.
+
             save (bool, optional): whether the plots should be saved or not. Defaults to False.
+
             n_clouds (int, optional): Number of word clouds that are plotted. Defaults to 1.
 
         Raises:
             ValueError: If save_name is not a string: no "Please specify a string as the name under which the plots should be saved"
-
-        Returns:
-            None:
         """
 
-        if bow_corpus == None:
+        if bow_corpus is None:
             bow_corpus = self.bow_corpus
 
-        if dictionary == None:
+        if dictionary is None:
             dictionary = self.dictionary
 
-        if lda_model == None:
+        if lda_model is None:
             lda_model = self.lda_model
 
         lda.LDA.visualize_topics(
